matminer.utils.tests package — matminer 0.6.3 documentation

# matminer.utils.tests package

## Submodules

## matminer.utils.tests.test_caching module

class `matminer.utils.tests.test_caching.` `TestCaching`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `test_cache`()

## matminer.utils.tests.test_conversions module

class `matminer.utils.tests.test_conversions.` `TestConversions`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_composition_to_oxidcomposition`()
  `test_dict_to_object`()
  `test_json_to_object`()
  `test_str_to_composition`()
  `test_structure_to_composition`()
  `test_structure_to_oxidstructure`()
  `test_to_istructure`()

## matminer.utils.tests.test_data module

class `matminer.utils.tests.test_data.` `TestDemlData`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Tests for the DemlData Class

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_oxidation`()
  `test_get_property`()

class `matminer.utils.tests.test_data.` `TestIUCrBondValenceData`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_data`()

class `matminer.utils.tests.test_data.` `TestMEGNetData`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_property`()

class `matminer.utils.tests.test_data.` `TestMagpieData`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_oxidation`()
  `test_get_property`()

class `matminer.utils.tests.test_data.` `TestMatScholarData`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_property`()

class `matminer.utils.tests.test_data.` `TestMixingEnthalpy`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_data`()

class `matminer.utils.tests.test_data.` `TestPymatgenData`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_oxidation`()
  `test_get_property`()

## matminer.utils.tests.test_flatten_dict module

class `matminer.utils.tests.test_flatten_dict.` `FlattenDictTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_flatten_nested_dict`()

## matminer.utils.tests.test_io module

class `matminer.utils.tests.test_io.` `IOTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `tearDown`()

    Hook method for deconstructing the test fixture after testing it.

  `test_load_dataframe_from_json`()
  `test_store_dataframe_as_json`()

`matminer.utils.tests.test_io.` `generate_json_files`()

## Module contents